phase\_curve\_tools package
===========================

Submodules
----------

phase\_curve\_tools.bestFit module
----------------------------------

.. automodule:: phase_curve_tools.bestFit
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.hg module
-----------------------------

.. automodule:: phase_curve_tools.hg
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.hg module
-----------------------------

.. automodule:: phase_curve_tools.hg
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.hg module
-----------------------------

.. automodule:: phase_curve_tools.hg
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.reducedMag module
-------------------------------------

.. automodule:: phase_curve_tools.reducedMag
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.reducedMag module
-------------------------------------

.. automodule:: phase_curve_tools.reducedMag
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.reducedMag module
-------------------------------------

.. automodule:: phase_curve_tools.reducedMag
   :members:
   :undoc-members:
   :show-inheritance:

phase\_curve\_tools.useAstroQuery module
----------------------------------------

.. automodule:: phase_curve_tools.useAstroQuery
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: phase_curve_tools
   :members:
   :undoc-members:
   :show-inheritance:


.. footbibliography::